@@ -34,7 +34,8 @@
 static char sccsid[] = "@(#)bt_open.c	8.10 (Berkeley) 8/17/94";
 #endif /* LIBC_SCCS and not lint */
 
-/*
+/**
+ * @file
  * Implementation of btree access method for 4.4BSD.
  *
  * The design here was originally based on that of the btree access method
@@ -83,20 +84,19 @@ static int byteorder(void);
 static int nroot(BTREE *);
 static int tmp(void);
 
-/*
+/**
  * __BT_OPEN -- Open a btree.
  *
- * Creates and fills a DB struct, and calls the routine that actually
+ * Creates and fills a #DB struct, and calls the routine that actually
  * opens the btree.
  *
- * Parameters:
- *	fname:	filename (NULL for in-memory trees)
- *	flags:	open flag bits
- *	mode:	open permission bits
- *	b:	BTREEINFO pointer
+ *	@param fname	filename (@CODE{NULL} for in-memory trees)
+ *	@param flags	open flag bits
+ *	@param mode	open permission bits
+ *	@param openinfo	#BTREEINFO pointer
+ *	@param dflags
  *
- * Returns:
- *	NULL on failure, pointer to DB on success.
+ * @return @CODE{NULL} on failure, pointer to #DB on success.
  *
  */
 DB *
@@ -359,14 +359,12 @@ err:	if (t) {
 	return (NULL);
 }
 
-/*
+/**
  * NROOT -- Create the root of a new tree.
  *
- * Parameters:
- *	t:	tree
+ *	@param t	tree
  *
- * Returns:
- *	RET_ERROR, RET_SUCCESS
+ * @return #RET_ERROR, #RET_SUCCESS
  */
 static int
 nroot(t)
@@ -403,7 +401,7 @@ nroot(t)
 }
 
 static int
-tmp()
+tmp(void)
 {
 	sigset_t set, oset;
 	int fd;
@@ -433,7 +431,7 @@ tmp()
 }
 
 static int
-byteorder()
+byteorder(void)
 {
 	u_int32_t x;
 	u_char *p;
