@@ -31,12 +31,13 @@
 #include "die.h"
 #include "locatestring.h"
 
-/*
+/** @file
 
 String locator: usage and memory status
 
         'v': result pointer
  
+@code
 string = "ABC XYZ XYZ ABC"
 
 pointer = locatestring(string, "XYZ", MATCH_FIRST);
@@ -66,13 +67,13 @@ pointer = locatestring(string, "ABC XYZ XYZ ABC", MATCH_COMPLETE);
 pointer = locatestring(string, "xyZ", MATCH_FIRST|IGNORE_CASE);
              v
         "ABC XYZ XYZ ABC"
-
+@endcode
  */
 
-/*
+/**
  * strincmp: strncmp with ignoring case.
  *
- *	Interface is same with strncmp.
+ *	Interface is same with @NAME{strncmp}.
  */
 static int
 strincmp(const char *string, const char *pattern, size_t len)
@@ -80,30 +81,36 @@ strincmp(const char *string, const char *pattern, size_t len)
 	unsigned char s, p;
 
 	while (len--) {
-		s = tolower((unsigned char)*string++);
-		p = tolower((unsigned char)*pattern++);
+		/*
+		 * In some systems, tolower() are #define macros,
+		 * where the argument gets evaluated more than once.
+		 */
+		s = tolower((unsigned char)*string);
+		p = tolower((unsigned char)*pattern);
 		if (s != p)
 			return s - p;
 		if (s == 0)
 			break;
+		string++;
+		pattern++;
 	}
 	return 0;
 }
 
-/*
+/**
  * locatestring: locate pattern from string
  *
- *	i)	string	string
- *	i)	pattern	pattern
- *	i)	flag	MATCH_FIRST:	match first
- *			MATCH_AT_FIRST: match only at first column
- *			MATCH_LAST:	match last
- *			MATCH_AT_LAST:	match only at last column
- *			MATCH_COMPLETE	match completely
+ *	@param[in]	string	string
+ *	@param[in]	pattern	pattern
+ *	@param[in]	flag	MATCH_FIRST:	match first <br>
+ *			MATCH_AT_FIRST: match only at first column <br>
+ *			MATCH_LAST:	match last <br>
+ *			MATCH_AT_LAST:	match only at last column <br>
+ *			MATCH_COMPLETE	match completely <br>
  *			IGNORE_CASE:	Ignore case
- *	r)		pointer or NULL
- *			If the flag == MATCH_AT_FIRST then the pointer
- *			points the following character of the matched
+ *	@return		pointer or NULL
+ *			If the flag == MATCH_AT_FIRST then the pointer <br>
+ *			points the following character of the matched <br>
  *			string, else points at the head of it.
  *
  * This function is made to avoid compatibility problems.
